/*
* file CcViewAccessInfo.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcViewAccessInfo
*
*  Copyright IBM Corporation 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import java.util.Date;

/**
 * A ClearCase view has a set of defined events which record
 * users access to it, including view "created" event, view
 * "last modified" event, view "last accessed" event, view "last
 * private data read" event, view "last private data update" event,
 * and view "last config spec update" event.  CcViewAccessInfo provides
 * an interface for retrieving the set of information associated with
 * each of these events.
 */
public interface CcViewAccessInfo
{
    /**
     * Get the view "created" event info.
     * 
     * @return  Info related to view creation.
     */
    public EventInfo
    getCreatedEvent();

    /**
     * Get the view "last modified" event info.
     * 
     * @return  Info related to the view "last modified" event.
     */
    public EventInfo
    getLastModifiedEvent();

    /**
     * Get the view "last accessed" event info.
     * 
     * @return  Info related to the view "last accessed" event.
     */
    public EventInfo
    getLastAccessedEvent();

    /**
     * Get the view "last private data read" event info.
     * 
     * @return  Info related to the view "last private data read" event.
     */
    public EventInfo
    getLastPrivateDataReadEvent();

    /**
     * Get the view "last private data update" event info.
     * 
     * @return  Info related to the view "last private data update" event.
     */
    public EventInfo
    getLastPrivateDataUpdateEvent();

    /**
     * Get the view "last config spec update" event info.
     * 
     * @return  Info related to the view "last config spec update" event.
     */
    public EventInfo
    getLastConfigSpecUpdateEvent();

    /**
     * EventInfo provides an interface for retrieving
     * information related to a particular access event for a
     * ClearCase view.  This information includes the event date,
     * user, group, and host.
     */
    public interface EventInfo
    {
        /**
         * Get the date on which the event represented by this EventInfo object
         * occurred.
         * 
         * @return date of event
         */
        public Date
        getDate();
    	
        /**
         * Get the name of the user associated with the event represented by
         * this EventInfo object.
         * 
         * @return name of user associated with the event
         */
        public String
        getUserName();
    	
        /**
         * Get the group of the user associated with the event represented by
         * this EventInfo object.
         * 
         * @return group of user associated with the event
         */
        public String
        getGroupName();
    	
        /**
         * Get the host name associated with the event represented by
         * this EventInfo object.
         * 
         * @return name of the host associated with the event
         */
        public String
        getHostName();
    }
}
